An actor-based remote devtools server implementation. Only tested with nightly Firefox versions at time of writing. Largely based on reverse-engineering of Firefox chrome devtool logs and reading of code.
Functions
- start_
server - Spin up a devtools server that listens for connections on the specified port.